searchData={"items":[{"type":"module","title":"PDFShift","doc":"PDFShift API client for Elixir.\n\nThis module provides a simple interface to interact with the PDFShift API for:\n- Converting HTML or URLs to PDF\n- Checking credit usage","ref":"PDFShift.html"},{"type":"module","title":"Authentication - PDFShift","doc":"The client uses HTTP Basic Authentication with your PDFShift API key.\nSet the API key using one of these methods:\n\n1. Set the `PDFSHIFT_API_KEY` environment variable\n2. Pass the API key in the options to each function\n   ```elixir\n   PDFShift.convert(\"https://example.com\", %{}, api_key: \"your_api_key\")\n   ```","ref":"PDFShift.html#module-authentication"},{"type":"module","title":"Examples - PDFShift","doc":"Converting a URL to PDF:\n```elixir\nPDFShift.convert(\"https://example.com\")\n```\n\nConverting HTML content to PDF:\n```elixir\nPDFShift.convert(\"  Hello World  \")\n```\n\nConverting with additional options:\n```elixir\nPDFShift.convert(\"https://example.com\", %{\n  landscape: true,\n  format: \"A4\"\n})\n```\n\nChecking credit usage:\n```elixir\nPDFShift.credits()\n```","ref":"PDFShift.html#module-examples"},{"type":"function","title":"PDFShift.convert/3","doc":"Converts HTML content or a URL to a PDF document.","ref":"PDFShift.html#convert/3"},{"type":"function","title":"Parameters - PDFShift.convert/3","doc":"* `source` - URL or HTML content to convert to PDF\n  * `options` - Additional options for the conversion (see \"Options\" below)\n  * `config_opts` - Configuration options for the client (`:api_key`, `:base_url`)","ref":"PDFShift.html#convert/3-parameters"},{"type":"function","title":"Options - PDFShift.convert/3","doc":"* `sandbox` - Will generate documents that don't count towards your credits. The generated document will come with a watermark.  * `encode` - Will return the generated PDF in Base64 encoded format, instead of raw.  * `filename` - Name of the destination file. If given, the response will be a JSON with a URL to download the file.  * `webhook` - An URL where PDFShift will send a POST request with the conversion result.  * `s3_destination` - Path to your S3 bucket to save the converted PDF directly into your AWS S3 account.  * `timeout` - Will kill the page loading at a specified time without stopping with a TimeoutError (in seconds).  * `wait_for` - Name of a function available globally. PDFShift will wait for this function to return a truthy value.  * `landscape` - Will set the view in landscape mode instead of portrait.  * `lazy_load_images` - Will load images that are otherwise only loaded when they are visible.  * `css` - Will append CSS styles to the document. Can be a URL or a String of CSS rules.  * `javascript` - Will execute the given Javascript before saving. Can be a URL or a String of JS code.  * `disable_javascript` - Will not execute any javascript in the document.  * `disable_backgrounds` - The final document will not have background images.  * `remove_blank` - Remove the last page if it is considered empty.  * `delay` - In milliseconds. Will wait for this duration before capturing the document (max 10 seconds).  * `raise_for_status` - Will stop the conversion if the status_code from the given source is not 2XX.  * `use_print` - Use the print stylesheet instead of the general one.  * `format` - Format of the document. Standard values (A4, Letter, etc.) or custom width x height.  * `pages` - Pages to print. Can be one number, a range, a list or a combination.  * `zoom` - A value between 0 and 2. Controls zoom level in the document.  * `is_gdpr` - If true, ensures data protection compliance by refusing certain features.  * `is_hipaa` - If true, ensures HIPAA compliance by refusing certain features.  * `margin` - Object defining empty spaces around the content (top, right, bottom, left).  * `auth` - Object containing username and password for accessing password-protected content.  * `cookies` - List of cookies to send along with the requests when loading the source.  * `http_headers` - List of HTTP headers to pass to the request.  * `header` - Object defining a custom header with source and height properties.  * `footer` - Object defining a custom footer with source and height properties.  * `protection` - Object defining PDF restrictions and passwords.  * `watermark` - Object defining a watermark to add to the document.","ref":"PDFShift.html#convert/3-options"},{"type":"function","title":"Examples - PDFShift.convert/3","doc":"iex> PDFShift.convert(\"https://example.com\")\n    {:ok, %{body: < >, status: 200, headers: [...]}}\n\n    iex> PDFShift.convert(\"  Hello world  \", %{sandbox: true})\n    {:ok, %{body: < >, status: 200, headers: [...]}}","ref":"PDFShift.html#convert/3-examples"},{"type":"function","title":"PDFShift.credits_usage/1","doc":"Get current credit usage information.","ref":"PDFShift.html#credits_usage/1"},{"type":"function","title":"Parameters - PDFShift.credits_usage/1","doc":"* `config_opts` - Configuration options for the client (`:api_key`, `:base_url`)","ref":"PDFShift.html#credits_usage/1-parameters"},{"type":"function","title":"Examples - PDFShift.credits_usage/1","doc":"iex> PDFShift.credits_usage()\n    {:ok, %{\n      body: %{\n        \"credits\" => %{\n          \"base\" => 50000,\n          \"remaining\" => 49881,\n          \"total\" => 50000,\n          \"used\" => 119\n        },\n        \"success\" => true\n      },\n      status: 200,\n      headers: [...]\n    }}","ref":"PDFShift.html#credits_usage/1-examples"},{"type":"module","title":"PDFShift.API","doc":"Module implementing the PDFShift API endpoints.","ref":"PDFShift.API.html"},{"type":"function","title":"PDFShift.API.convert/5","doc":"Converts a HTML document or URL to PDF.","ref":"PDFShift.API.html#convert/5"},{"type":"function","title":"Parameters - PDFShift.API.convert/5","doc":"* `client` - The HTTP client module\n  * `config` - The configuration struct\n  * `source` - URL or HTML content to convert to PDF\n  * `options` - Additional options for the conversion","ref":"PDFShift.API.html#convert/5-parameters"},{"type":"function","title":"Returns - PDFShift.API.convert/5","doc":"* `{:ok, response}` - On successful conversion\n  * `{:error, reason}` - On failure","ref":"PDFShift.API.html#convert/5-returns"},{"type":"function","title":"Examples - PDFShift.API.convert/5","doc":"iex> PDFShift.API.convert(PDFShift.Client, config, \"https://example.com\")\n    {:ok, %{body: < >, status: 200, headers: [...]}}","ref":"PDFShift.API.html#convert/5-examples"},{"type":"function","title":"PDFShift.API.credits_usage/3","doc":"Gets the current credits usage.","ref":"PDFShift.API.html#credits_usage/3"},{"type":"function","title":"Parameters - PDFShift.API.credits_usage/3","doc":"* `client` - The HTTP client module\n  * `config` - The configuration struct","ref":"PDFShift.API.html#credits_usage/3-parameters"},{"type":"function","title":"Returns - PDFShift.API.credits_usage/3","doc":"* `{:ok, response}` - On successful request\n  * `{:error, reason}` - On failure","ref":"PDFShift.API.html#credits_usage/3-returns"},{"type":"function","title":"Examples - PDFShift.API.credits_usage/3","doc":"iex> PDFShift.API.credits_usage(PDFShift.Client, config)\n    {:ok, %{\n      body: %{\n        \"credits\" => %{\n          \"base\" => 50000,\n          \"remaining\" => 49881,\n          \"total\" => 50000,\n          \"used\" => 119\n        },\n        \"success\" => true\n      },\n      status: 200,\n      headers: [...]\n    }}","ref":"PDFShift.API.html#credits_usage/3-examples"},{"type":"module","title":"PDFShift.Client","doc":"HTTP client for PDFShift API.","ref":"PDFShift.Client.html"},{"type":"function","title":"PDFShift.Client.get/3","doc":"Performs a GET request to the PDFShift API.","ref":"PDFShift.Client.html#get/3"},{"type":"function","title":"PDFShift.Client.post/4","doc":"Performs a POST request to the PDFShift API.","ref":"PDFShift.Client.html#post/4"},{"type":"behaviour","title":"PDFShift.ClientBehaviour","doc":"Behaviour specification for PDFShift API client.","ref":"PDFShift.ClientBehaviour.html"},{"type":"callback","title":"PDFShift.ClientBehaviour.get/3","doc":"","ref":"PDFShift.ClientBehaviour.html#c:get/3"},{"type":"callback","title":"PDFShift.ClientBehaviour.post/4","doc":"","ref":"PDFShift.ClientBehaviour.html#c:post/4"},{"type":"module","title":"PDFShift.Config","doc":"Configuration module for PDFShift API client.","ref":"PDFShift.Config.html"},{"type":"function","title":"PDFShift.Config.get_api_key_from_env/0","doc":"Gets the API key from environment variables.","ref":"PDFShift.Config.html#get_api_key_from_env/0"},{"type":"function","title":"PDFShift.Config.new/1","doc":"Creates a new configuration with the given options.","ref":"PDFShift.Config.html#new/1"},{"type":"function","title":"Options - PDFShift.Config.new/1","doc":"* `:api_key` - API key for authentication with PDFShift\n  * `:base_url` - Base URL for the PDFShift API (defaults to \"https://api.pdfshift.io/v3\")","ref":"PDFShift.Config.html#new/1-options"},{"type":"function","title":"Examples - PDFShift.Config.new/1","doc":"iex> PDFShift.Config.new(api_key: \"api_key123\")\n    %PDFShift.Config{api_key: \"api_key123\", base_url: \"https://api.pdfshift.io/v3\"}","ref":"PDFShift.Config.html#new/1-examples"},{"type":"type","title":"PDFShift.Config.t/0","doc":"","ref":"PDFShift.Config.html#t:t/0"},{"type":"module","title":"PDFShift.Types","doc":"Type definitions for the PDFShift API.","ref":"PDFShift.Types.html"},{"type":"type","title":"PDFShift.Types.auth/0","doc":"Authentication settings for password-protected content.","ref":"PDFShift.Types.html#t:auth/0"},{"type":"type","title":"PDFShift.Types.convert_options/0","doc":"Request options for converting HTML/URL to PDF.","ref":"PDFShift.Types.html#t:convert_options/0"},{"type":"type","title":"PDFShift.Types.cookie/0","doc":"Cookie settings for requests when loading the source.","ref":"PDFShift.Types.html#t:cookie/0"},{"type":"type","title":"PDFShift.Types.credits_response/0","doc":"Credits usage response.","ref":"PDFShift.Types.html#t:credits_response/0"},{"type":"type","title":"PDFShift.Types.error_response/0","doc":"Error response.","ref":"PDFShift.Types.html#t:error_response/0"},{"type":"type","title":"PDFShift.Types.footer/0","doc":"Footer settings for the generated PDF.","ref":"PDFShift.Types.html#t:footer/0"},{"type":"type","title":"PDFShift.Types.header/0","doc":"Header settings for the generated PDF.","ref":"PDFShift.Types.html#t:header/0"},{"type":"type","title":"PDFShift.Types.http_headers/0","doc":"HTTP headers for requests when loading the source.","ref":"PDFShift.Types.html#t:http_headers/0"},{"type":"type","title":"PDFShift.Types.margin/0","doc":"Margin settings for the generated PDF.","ref":"PDFShift.Types.html#t:margin/0"},{"type":"type","title":"PDFShift.Types.pdf_response_headers/0","doc":"Response headers from the PDF conversion.","ref":"PDFShift.Types.html#t:pdf_response_headers/0"},{"type":"type","title":"PDFShift.Types.protection/0","doc":"Protection settings for the generated PDF.","ref":"PDFShift.Types.html#t:protection/0"},{"type":"type","title":"PDFShift.Types.watermark/0","doc":"Watermark settings for the generated PDF.","ref":"PDFShift.Types.html#t:watermark/0"},{"type":"extras","title":"PDFShift","doc":"# PDFShift\n\nAn Elixir client for the [PDFShift API](https://pdfshift.io), which allows you to convert HTML to PDF.","ref":"readme.html"},{"type":"extras","title":"Installation - PDFShift","doc":"The package can be installed by adding `pdf_shift` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:pdf_shift, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - PDFShift","doc":"You need a PDFShift API key to use this client. You can get one by signing up at [PDFShift](https://pdfshift.io).\n\nSet your API key using one of these methods:\n\n1. Set the `PDFSHIFT_API_KEY` environment variable\n2. Pass the API key in the options to each function\n   ```elixir\n   PDFShift.convert(\"https://example.com\", %{}, api_key: \"your_api_key\")\n   ```","ref":"readme.html#configuration"},{"type":"extras","title":"Usage - PDFShift","doc":"","ref":"readme.html#usage"},{"type":"extras","title":"Converting a URL to PDF - PDFShift","doc":"```elixir\nPDFShift.convert(\"https://example.com\")\n```","ref":"readme.html#converting-a-url-to-pdf"},{"type":"extras","title":"Converting HTML content to PDF - PDFShift","doc":"```elixir\nPDFShift.convert(\"  Hello World  \")\n```","ref":"readme.html#converting-html-content-to-pdf"},{"type":"extras","title":"Converting with options - PDFShift","doc":"```elixir\nPDFShift.convert(\"https://example.com\", %{\n  landscape: true,\n  format: \"A4\",\n  margin: %{\n    top: \"1cm\",\n    right: \"1cm\",\n    bottom: \"1cm\",\n    left: \"1cm\"\n  },\n  header: %{\n    source: \" Header \",\n    height: \"2cm\"\n  },\n  footer: %{\n    source: \" Page {{page}} of {{total}} \",\n    height: \"2cm\"\n  }\n})\n```","ref":"readme.html#converting-with-options"},{"type":"extras","title":"Check credit usage - PDFShift","doc":"```elixir\nPDFShift.credits()\n```","ref":"readme.html#check-credit-usage"},{"type":"extras","title":"Available options - PDFShift","doc":"The following options can be passed to the `convert/3` function:\n\n- `sandbox` - Will generate documents that don't count towards your credits. The generated document will come with a watermark.\n- `encode` - Will return the generated PDF in Base64 encoded format, instead of raw.\n- `filename` - Name of the destination file. If given, the response will be a JSON with a URL to download the file.\n- `webhook` - An URL where PDFShift will send a POST request with the conversion result.\n- `s3_destination` - Path to your S3 bucket to save the converted PDF directly into your AWS S3 account.\n- `timeout` - Will kill the page loading at a specified time without stopping with a TimeoutError (in seconds).\n- `wait_for` - Name of a function available globally. PDFShift will wait for this function to return a truthy value.\n- `landscape` - Will set the view in landscape mode instead of portrait.\n- `lazy_load_images` - Will load images that are otherwise only loaded when they are visible.\n- `css` - Will append CSS styles to the document. Can be a URL or a String of CSS rules.\n- `javascript` - Will execute the given Javascript before saving. Can be a URL or a String of JS code.\n- `disable_javascript` - Will not execute any javascript in the document.\n- `disable_backgrounds` - The final document will not have background images.\n- `remove_blank` - Remove the last page if it is considered empty.\n- `delay` - In milliseconds. Will wait for this duration before capturing the document (max 10 seconds).\n- `raise_for_status` - Will stop the conversion if the status_code from the given source is not 2XX.\n- `use_print` - Use the print stylesheet instead of the general one.\n- `format` - Format of the document. Standard values (A4, Letter, etc.) or custom width x height.\n- `pages` - Pages to print. Can be one number, a range, a list or a combination.\n- `zoom` - A value between 0 and 2. Controls zoom level in the document.\n- `is_gdpr` - If true, ensures data protection compliance by refusing certain features.\n- `is_hipaa` - If true, ensures HIPAA compliance by refusing certain features.\n- `margin` - Object defining empty spaces around the content (top, right, bottom, left).\n- `auth` - Object containing username and password for accessing password-protected content.\n- `cookies` - List of cookies to send along with the requests when loading the source.\n- `http_headers` - List of HTTP headers to pass to the request.\n- `header` - Object defining a custom header with source and height properties.\n- `footer` - Object defining a custom footer with source and height properties.\n- `protection` - Object defining PDF restrictions and passwords.\n- `watermark` - Object defining a watermark to add to the document.","ref":"readme.html#available-options"},{"type":"extras","title":"Development - PDFShift","doc":"After checking out the repo, run `mix deps.get` to install dependencies. Then, run `mix test` to run the tests.","ref":"readme.html#development"},{"type":"extras","title":"License - PDFShift","doc":"The package is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project will be documented in this file. See [Keep a\nCHANGELOG](http://keepachangelog.com/) for how to update this file. This project\nadheres to [Semantic Versioning](http://semver.org/).\n\n<!-- %% CHANGELOG_ENTRIES %% -->","ref":"changelog.html"},{"type":"extras","title":"0.1.0 - 2025-04-08 - Changelog","doc":"Initial release. :rocket:","ref":"changelog.html#0-1-0-2025-04-08"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}